@@ -9,10 +9,13 @@ from django.core.exceptions import ImproperlyConfigured
 from django.db import models, transaction, IntegrityError
 from django.db.models.fields import FieldDoesNotExist
 from django.db.models.query import QuerySet
-from django.utils.timezone import utc
-from vkontakte_api import fields
-from vkontakte_api.signals import vkontakte_api_post_fetch
-from vkontakte_api.utils import api_call, VkontakteError
+from django.utils import timezone
+
+from . import fields
+from .exceptions import VkontakteDeniedAccessError, VkontakteContentError, VkontakteParseError, WrongResponseType
+from .signals import vkontakte_api_post_fetch
+from .utils import api_call, VkontakteError
+
 
 log = logging.getLogger('vkontakte_api')
 
@@ -20,22 +23,6 @@ COMMIT_REMOTE = getattr(settings, 'VKONTAKTE_API_COMMIT_REMOTE', True)
 MASTER_DATABASE = getattr(settings, 'VKONTAKTE_API_MASTER_DATABASE', 'default')
 
 
-class VkontakteDeniedAccessError(Exception):
-    pass
-
-
-class VkontakteContentError(Exception):
-    pass
-
-
-class VkontakteParseError(Exception):
-    pass
-
-
-class WrongResponseType(Exception):
-    pass
-
-
 class VkontakteManager(models.Manager):
 
     '''
@@ -76,13 +63,15 @@ class VkontakteManager(models.Manager):
                 return None
 
             if response['type'] not in self.model.resolve_screen_name_types:
-                raise WrongResponseType("Method get_by_slug returned instance with wrong type '%s', not '%s'. Slug is '%s'" % (response['type'], self.model.resolve_screen_name_types, slug))
+                raise WrongResponseType("Method get_by_slug returned instance with wrong type '%s', not '%s'. Slug is '%s'" % (
+                    response['type'], self.model.resolve_screen_name_types, slug))
 
             try:
                 remote_id = int(response['object_id'])
             except (KeyError, TypeError, ValueError), e:
                 # TODO: raise error
-                log.error("Method get_by_slug returned response in strange format: %s. Slug is '%s'" % (response, slug))
+                log.error("Method get_by_slug returned response in strange format: %s. Slug is '%s'" %
+                          (response, slug))
                 return None
 
         try:
@@ -141,7 +130,9 @@ class VkontakteManager(models.Manager):
         if isinstance(result, list):
             # python 2.6 compatibility
             return self.model.objects.filter(pk__in=set([self.get_or_create_from_instance(instance).pk for instance in result]))
-#            return self.model.objects.filter(pk__in={self.get_or_create_from_instance(instance).pk for instance in result})
+#         return
+#         self.model.objects.filter(pk__in={self.get_or_create_from_instance(instance).pk
+#         for instance in result})
         elif isinstance(result, QuerySet):
             return result
         else:
@@ -153,10 +144,14 @@ class VkontakteManager(models.Manager):
         TODO: rename everywhere extra_fields to _extra_fields
         '''
         extra_fields = kwargs.pop('extra_fields', {})
-        extra_fields['fetched'] = datetime.now()
+        extra_fields['fetched'] = timezone.now()
 
         response = self.api_call(*args, **kwargs)
 
+        version = float(kwargs.get('v', 0))
+        if version >= 4.93:
+            response = response['items']
+
         return self.parse_response(response, extra_fields)
 
     def parse_response(self, response, extra_fields=None):
@@ -213,7 +208,7 @@ class VkontakteTimelineManager(VkontakteManager):
     timeline_force_ordering = False
 
     def get_timeline_date(self, instance):
-        return getattr(instance, self.timeline_cut_fieldname, datetime(1970, 1, 1).replace(tzinfo=utc))
+        return getattr(instance, self.timeline_cut_fieldname, datetime(1970, 1, 1).replace(tzinfo=timezone.utc))
 
     @transaction.commit_on_success
     def fetch(self, *args, **kwargs):
@@ -316,7 +311,7 @@ class VkontakteModel(models.Model):
                 try:
                     value = int(value)
                     assert value > 0
-                    value = datetime.utcfromtimestamp(value).replace(tzinfo=utc)
+                    value = datetime.utcfromtimestamp(value).replace(tzinfo=timezone.utc)
                 except:
                     value = None
             elif isinstance(field, models.DateField):
@@ -351,7 +346,8 @@ class VkontakteModel(models.Model):
         if len(objects) == 1:
             self.__dict__.update(objects[0].__dict__)
         else:
-            raise VkontakteContentError("Remote server returned more objects, than expected - %d instead of one. Object details: %s, request details: %s" % (len(objects), self.__dict__, kwargs))
+            raise VkontakteContentError(
+                "Remote server returned more objects, than expected - %d instead of one. Object details: %s, request details: %s" % (len(objects), self.__dict__, kwargs))
 
     def get_url(self):
         return 'http://vk.com/%s' % self.slug
